@@ -19,9 +19,9 @@
  *  DISCLAIMED. This includes but is not limited to warranties of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  *
- * $Revision: 1.3 $
- * $Author: dannysmith $
- * $Date: 2001/11/29 04:26:33 $
+ * $Revision: 1.4 $
+ * $Author: earnie $
+ * $Date: 2003/02/21 21:19:51 $
  *
  */
 
@@ -39,26 +39,25 @@
 extern "C" {
 #endif
 
+_CRTIMP char* __cdecl	_cgets (char*);
+_CRTIMP int __cdecl	_cprintf (const char*, ...);
+_CRTIMP int __cdecl	_cputs (const char*);
+_CRTIMP int __cdecl	_cscanf (char*, ...);
 
-char*	_cgets (char*);
-int	_cprintf (const char*, ...);
-int	_cputs (const char*);
-int	_cscanf (char*, ...);
-
-int	_getch (void);
-int	_getche (void);
-int	_kbhit (void);
-int	_putch (int);
-int	_ungetch (int);
+_CRTIMP int __cdecl	_getch (void);
+_CRTIMP int __cdecl	_getche (void);
+_CRTIMP int __cdecl	_kbhit (void);
+_CRTIMP int __cdecl	_putch (int);
+_CRTIMP int __cdecl	_ungetch (int);
 
 
 #ifndef	_NO_OLDNAMES
 
-int	getch (void);
-int	getche (void);
-int	kbhit (void);
-int	putch (int);
-int	ungetch (int);
+_CRTIMP int __cdecl	getch (void);
+_CRTIMP int __cdecl	getche (void);
+_CRTIMP int __cdecl	kbhit (void);
+_CRTIMP int __cdecl	putch (int);
+_CRTIMP int __cdecl	ungetch (int);
 
 #endif	/* Not _NO_OLDNAMES */
 
